@@ -13,7 +13,11 @@ import pydub
 import speech_recognition
 from playwright.async_api import Frame, Locator, Page, Response
 
-from playwright_recaptcha.errors import RecaptchaRateLimitError, RecaptchaSolveError
+from playwright_recaptcha.errors import (
+    RecaptchaNotFoundError,
+    RecaptchaRateLimitError,
+    RecaptchaSolveError,
+)
 from playwright_recaptcha.recaptchav2.utils import (
     get_recaptcha_checkbox,
     get_recaptcha_frame,
@@ -48,7 +52,7 @@ class AsyncSolver:
     RecaptchaNotFoundError
         If the reCAPTCHA was not found.
     RecaptchaRateLimitError
-        If the reCAPTCHA rate limit has been reached.
+        If the reCAPTCHA rate limit has been exceeded.
     RecaptchaSolveError
         If the reCAPTCHA could not be solved.
     """
@@ -56,7 +60,7 @@ class AsyncSolver:
     def __init__(self, page: Page, retries: int = 3) -> None:
         self._page = page
         self._retries = retries
-        self.token = None
+        self.token: Optional[str] = None
 
     def __repr__(self) -> str:
         return f"AsyncSolver(page={self._page!r}, retries={self._retries!r})"
@@ -206,7 +210,7 @@ class AsyncSolver:
         await textbox.fill(text)
         await verify_button.click()
 
-        while True:
+        while not recaptcha_frame.is_detached():
             solve_failure = recaptcha_frame.get_by_text(
                 "Multiple correct solutions required - please solve more."
             )
@@ -214,8 +218,8 @@ class AsyncSolver:
             rate_limit = recaptcha_frame.get_by_text("Try again later")
 
             if (
-                await solve_failure.is_visible()
-                or await recaptcha_checkbox.is_checked()
+                await recaptcha_checkbox.is_checked()
+                or await solve_failure.is_visible()
             ):
                 break
 
@@ -247,7 +251,9 @@ class AsyncSolver:
 
         Raises
         ------
-        RecapchaSolveError
+        RecaptchaNotFoundError
+            If the reCAPTCHA checkbox was not found.
+        RecaptchaSolveError
             If the reCAPTCHA could not be solved.
         """
         self._page.on("response", self._extract_token)
@@ -256,10 +262,27 @@ class AsyncSolver:
         await self._page.wait_for_load_state("networkidle")
         recaptcha_frame = get_recaptcha_frame(self._page.frames)
         recaptcha_checkbox = get_recaptcha_checkbox(self._page.frames)
-        await recaptcha_checkbox.click()
 
-        if await recaptcha_checkbox.is_checked():
-            return self.token
+        if await recaptcha_checkbox.is_hidden():
+            raise RecaptchaNotFoundError
+
+        await recaptcha_checkbox.click(force=True)
+
+        while True:
+            audio_challenge_button = recaptcha_frame.get_by_role(
+                "button", name="Get an audio challenge"
+            )
+
+            if await audio_challenge_button.is_enabled():
+                break
+
+            if await recaptcha_checkbox.is_checked():
+                if self.token is None:
+                    raise RecaptchaSolveError
+
+                return self.token
+
+            await self._page.wait_for_timeout(100)
 
         while retries > 0:
             await self._random_delay()
@@ -268,8 +291,11 @@ class AsyncSolver:
             await self._random_delay()
             await self._submit_audio_text(recaptcha_frame, recaptcha_checkbox, text)
 
-            if await recaptcha_checkbox.is_checked():
-                break
+            if recaptcha_frame.is_detached() or await recaptcha_checkbox.is_checked():
+                if self.token is None:
+                    raise RecaptchaSolveError
+
+                return self.token
 
             new_challenge_button = recaptcha_frame.get_by_role(
                 "button", name="Get a new challenge"
@@ -278,7 +304,4 @@ class AsyncSolver:
             await new_challenge_button.click()
             retries -= 1
 
-        if not await recaptcha_checkbox.is_checked():
-            raise RecaptchaSolveError
-
-        return self.token
+        raise RecaptchaSolveError
