@@ -10,7 +10,11 @@ import pydub
 import speech_recognition
 from playwright.sync_api import Frame, Locator, Page, Response
 
-from playwright_recaptcha.errors import RecaptchaRateLimitError, RecaptchaSolveError
+from playwright_recaptcha.errors import (
+    RecaptchaNotFoundError,
+    RecaptchaRateLimitError,
+    RecaptchaSolveError,
+)
 from playwright_recaptcha.recaptchav2.utils import (
     get_recaptcha_checkbox,
     get_recaptcha_frame,
@@ -45,7 +49,7 @@ class SyncSolver:
     RecaptchaNotFoundError
         If the reCAPTCHA was not found.
     RecaptchaRateLimitError
-        If the reCAPTCHA rate limit has been reached.
+        If the reCAPTCHA rate limit has been exceeded.
     RecaptchaSolveError
         If the reCAPTCHA could not be solved.
     """
@@ -53,7 +57,7 @@ class SyncSolver:
     def __init__(self, page: Page, retries: int = 3) -> None:
         self._page = page
         self._retries = retries
-        self.token = None
+        self.token: Optional[str] = None
 
     def __repr__(self) -> str:
         return f"SyncSolver(page={self._page!r}, retries={self._retries!r})"
@@ -177,12 +181,12 @@ class SyncSolver:
         recaptcha_frame.get_by_role("textbox", name="Enter what you hear").fill(text)
         recaptcha_frame.get_by_role("button", name="Verify").click()
 
-        while True:
+        while not recaptcha_frame.is_detached():
             if (
-                recaptcha_frame.get_by_text(
+                recaptcha_checkbox.is_checked()
+                or recaptcha_frame.get_by_text(
                     "Multiple correct solutions required - please solve more."
                 ).is_visible()
-                or recaptcha_checkbox.is_checked()
             ):
                 break
 
@@ -214,7 +218,9 @@ class SyncSolver:
 
         Raises
         ------
-        RecapchaSolveError
+        RecaptchaNotFoundError
+            If the reCAPTCHA checkbox was not found.
+        RecaptchaSolveError
             If the reCAPTCHA could not be solved.
         """
         self._page.on("response", self._extract_token)
@@ -223,10 +229,25 @@ class SyncSolver:
         self._page.wait_for_load_state("networkidle")
         recaptcha_frame = get_recaptcha_frame(self._page.frames)
         recaptcha_checkbox = get_recaptcha_checkbox(self._page.frames)
-        recaptcha_checkbox.click()
 
-        if recaptcha_checkbox.is_checked():
-            return self.token
+        if recaptcha_checkbox.is_hidden():
+            raise RecaptchaNotFoundError
+
+        recaptcha_checkbox.click(force=True)
+
+        while True:
+            if recaptcha_frame.get_by_role(
+                "button", name="Get an audio challenge"
+            ).is_enabled():
+                break
+
+            if recaptcha_checkbox.is_checked():
+                if self.token is None:
+                    raise RecaptchaSolveError
+
+                return self.token
+
+            self._page.wait_for_timeout(100)
 
         while retries > 0:
             self._random_delay()
@@ -235,13 +256,13 @@ class SyncSolver:
             self._random_delay()
             self._submit_audio_text(recaptcha_frame, recaptcha_checkbox, text)
 
-            if recaptcha_checkbox.is_checked():
-                break
+            if recaptcha_frame.is_detached() or recaptcha_checkbox.is_checked():
+                if self.token is None:
+                    raise RecaptchaSolveError
+
+                return self.token
 
             recaptcha_frame.get_by_role("button", name="Get a new challenge").click()
             retries -= 1
 
-        if not recaptcha_checkbox.is_checked():
-            raise RecaptchaSolveError
-
-        return self.token
+        raise RecaptchaSolveError
